==> hyakutyping-0.0.5.tar.gz: hyakutyping-0.0.5/src/OptionMenu_uni.h <==
#ifndef OPTION_MENU_UNI_H
#define OPTION_MENU_UNI_H

/*!
  \file
  \brief IvVj[ Unicode \[X`

  \author Satofumi KAMIMURA

  $Id$
*/

#include <SDL.h>

const static Uint16 OptionMenu_title[] = { 0x30aa, 0x30d7, 0x30b7, 0x30e7, 0x30f3, 0x0 }; // IvV
const static Uint16 OptionMenu_escape[] = { 'E', 'S', 'C', ' ', 0x3067, 0x623b, 0x308a, 0x307e, 0x3059, 0x0 }; // ESC Ŗ߂܂

const static Uint16 OptionMenu_typing[] = { 0x30bf, 0x30a4, 0x30d4, 0x30f3, 0x30b0, 0x8a2d, 0x5b9a, 0x0 }; // ^CsOݒ
const static Uint16 OptionMenu_typing_num[] = { 0x7df4, 0x7fd2, 0x6570, 0x0 }; // K
const static Uint16 OptionMenu_input[] = { 0x5165, 0x529b, 0x30e2, 0x30fc, 0x30c9, 0x0 }; // ̓[h
const static Uint16 OptionMenu_Roman[] = { 0x30ed, 0x30fc, 0x30de, 0x5b57, 0x5165, 0x529b, 0x0 }; // [}
const static Uint16 OptionMenu_Kana[] = { 0x304b, 0x306a, 0x5165, 0x529b, 0x0 }; // ȓ
const static Uint16 OptionMenu_eachtime_title[] = { 0x7df4, 0x7fd2, 0x8a2d, 0x5b9a, 0x0 }; // Kݒ
const static Uint16 OptionMenu_eachtime[] = { 0x6bce, 0x56de, 0x3001, 0x540c, 0x3058, 0x53e5, 0x3092, 0x51fa, 0x984c, 0x3059, 0x308b, 0x0 }; // Ao肷

const static Uint16 OptionMenu_sound[] = { 0x97f3, 0x697d, 0x3001, 0x52b9, 0x679c, 0x97f3, 0x3001, 0x8a60, 0x307f, 0x4e0a, 0x3052, 0x0 }; // yAʉArݏグ
const static Uint16 OptionMenu_music[] = { 0x97f3, 0x697d, 0x0 }; // y
const static Uint16 OptionMenu_effect[] = { 0x52b9, 0x679c, 0x97f3, 0x0 }; // ʉ
const static Uint16 OptionMenu_voice[] = { 0x8a60, 0x307f, 0x4e0a, 0x3052, 0x0 }; // rݏグ
const static Uint16 OptionMenu_cdrom[] = { 'C', 'D', '-', 'R', 'O', 'M', 0x0 }; // CD-ROM

const static Uint16 OptionMenu_system[] = { 0x30b7, 0x30b9, 0x30c6, 0x30e0, 0x0 }; // VXe
const static Uint16 OptionMenu_full_title[] = { 0x753b, 0x9762, 0x30e2, 0x30fc, 0x30c9, 0x0 }; // ʃ[h
const static Uint16 OptionMenu_full[] = { 0x30d5, 0x30eb, 0x30b9, 0x30af, 0x30ea, 0x30fc, 0x30f3, 0x0 }; // tXN[
const static Uint16 OptionMenu_send_title[] = { 0x30b9, 0x30b3, 0x30a2, 0x767b, 0x9332, 0x0 }; // XRAo^
const static Uint16 OptionMenu_send[] = { 0x30c7, 0x30fc, 0x30bf, 0x3092, 0x30b5, 0x30fc, 0x30d0, 0x306b, 0x9001, 0x4fe1, 0x0 }; // f[^T[oɑM

#endif /* ! OPTION_MENU_UNI_H */

==> hyakutyping-0.1.1.tar.gz: hyakutyping-0.1.1/src/OptionMenu_uni.h <==
#ifndef OPTION_MENU_UNI_H
#define OPTION_MENU_UNI_H

/*!
  \file
  \brief IvVj[ Unicode \[X`

  \author Satofumi KAMIMURA

  $Id$
*/

#include <SDL.h>

const static Uint16 OptionMenu_title[] = { 0x30aa, 0x30d7, 0x30b7, 0x30e7, 0x30f3, 0x0 }; // IvV
const static Uint16 OptionMenu_escape[] = { 'E', 'S', 'C', ' ', 0x3067, 0x623b, 0x308a, 0x307e, 0x3059, 0x0 }; // ESC Ŗ߂܂

const static Uint16 OptionMenu_typing[] = { 0x30bf, 0x30a4, 0x30d4, 0x30f3, 0x30b0, 0x8a2d, 0x5b9a, 0x0 }; // ^CsOݒ
const static Uint16 OptionMenu_typing_num[] = { 0x7df4, 0x7fd2, 0x6570, 0x0 }; // K
const static Uint16 OptionMenu_input[] = { 0x5165, 0x529b, 0x30e2, 0x30fc, 0x30c9, 0x0 }; // ̓[h
const static Uint16 OptionMenu_Roman[] = { 0x30ed, 0x30fc, 0x30de, 0x5b57, 0x5165, 0x529b, 0x0 }; // [}
const static Uint16 OptionMenu_Kana[] = { 0x304b, 0x306a, 0x5165, 0x529b, 0x0 }; // ȓ
const static Uint16 OptionMenu_eachtime_title[] = { 0x7df4, 0x7fd2, 0x8a2d, 0x5b9a, 0x0 }; // Kݒ
const static Uint16 OptionMenu_eachtime[] = { 0x6bce, 0x56de, 0x3001, 0x540c, 0x3058, 0x53e5, 0x3092, 0x51fa, 0x984c, 0x3059, 0x308b, 0x0 }; // Ao肷

const static Uint16 OptionMenu_sound[] = { 0x97f3, 0x697d, 0x3001, 0x52b9, 0x679c, 0x97f3, 0x3001, 0x8a60, 0x307f, 0x4e0a, 0x3052, 0x0 }; // yAʉArݏグ
const static Uint16 OptionMenu_music[] = { 0x97f3, 0x697d, 0x0 }; // y
const static Uint16 OptionMenu_effect[] = { 0x52b9, 0x679c, 0x97f3, 0x0 }; // ʉ
const static Uint16 OptionMenu_voice[] = { 0x8a60, 0x307f, 0x4e0a, 0x3052, 0x0 }; // rݏグ
//const static Uint16 OptionMenu_cdrom[] = { 'C', 'D', '-', 'R', 'O', 'M', 0x0 }; // CD-ROM

const static Uint16 OptionMenu_system[] = { 0x30b7, 0x30b9, 0x30c6, 0x30e0, 0x0 }; // VXe
const static Uint16 OptionMenu_full_title[] = { 0x753b, 0x9762, 0x30e2, 0x30fc, 0x30c9, 0x0 }; // ʃ[h
const static Uint16 OptionMenu_full[] = { 0x30d5, 0x30eb, 0x30b9, 0x30af, 0x30ea, 0x30fc, 0x30f3, 0x0 }; // tXN[
const static Uint16 OptionMenu_send_title[] = { 0x30b9, 0x30b3, 0x30a2, 0x767b, 0x9332, 0x0 }; // XRAo^
const static Uint16 OptionMenu_send[] = { 0x30c7, 0x30fc, 0x30bf, 0x3092, 0x30b5, 0x30fc, 0x30d0, 0x306b, 0x9001, 0x4fe1, 0x0 }; // f[^T[oɑM

#endif /* ! OPTION_MENU_UNI_H */
